diff --git a/sdk/datafactory/mgmt-v2018_06_01/pom.xml b/sdk/datafactory/mgmt-v2018_06_01/pom.xml
index 79145c162701b..6a01bee79fc62 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/pom.xml
+++ b/sdk/datafactory/mgmt-v2018_06_01/pom.xml
@@ -11,11 +11,11 @@
com.microsoft.azure
azure-arm-parent
- 1.3.2
- ../../parents/azure-arm-parent/pom.xml
+ 1.1.0
+ ../../../pom.management.xml
azure-mgmt-datafactory
- 1.0.0-beta-4
+ 1.0.0-beta
jar
Microsoft Azure SDK for DataFactory Management
This package contains Microsoft DataFactory Management SDK.
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/AvroWriteSettings.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/AvroWriteSettings.java
index 9ee2f49222ddf..139c2b133b0b3 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/AvroWriteSettings.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/AvroWriteSettings.java
@@ -30,6 +30,22 @@ public class AvroWriteSettings extends FormatWriteSettings {
@JsonProperty(value = "recordNamespace")
private String recordNamespace;
+ /**
+ * Limit the written file's row count to be smaller than or equal to the
+ * specified count. Type: integer (or Expression with resultType integer).
+ */
+ @JsonProperty(value = "maxRowsPerFile")
+ private Object maxRowsPerFile;
+
+ /**
+ * Specifies the file name pattern
+ * <fileNamePrefix>_<fileIndex>.<fileExtension> when copy
+ * from non-file based store without partitionOptions. Type: string (or
+ * Expression with resultType string).
+ */
+ @JsonProperty(value = "fileNamePrefix")
+ private Object fileNamePrefix;
+
/**
* Get top level record name in write result, which is required in AVRO spec.
*
@@ -70,4 +86,44 @@ public AvroWriteSettings withRecordNamespace(String recordNamespace) {
return this;
}
+ /**
+ * Get limit the written file's row count to be smaller than or equal to the specified count. Type: integer (or Expression with resultType integer).
+ *
+ * @return the maxRowsPerFile value
+ */
+ public Object maxRowsPerFile() {
+ return this.maxRowsPerFile;
+ }
+
+ /**
+ * Set limit the written file's row count to be smaller than or equal to the specified count. Type: integer (or Expression with resultType integer).
+ *
+ * @param maxRowsPerFile the maxRowsPerFile value to set
+ * @return the AvroWriteSettings object itself.
+ */
+ public AvroWriteSettings withMaxRowsPerFile(Object maxRowsPerFile) {
+ this.maxRowsPerFile = maxRowsPerFile;
+ return this;
+ }
+
+ /**
+ * Get specifies the file name pattern <fileNamePrefix>_<fileIndex>.<fileExtension> when copy from non-file based store without partitionOptions. Type: string (or Expression with resultType string).
+ *
+ * @return the fileNamePrefix value
+ */
+ public Object fileNamePrefix() {
+ return this.fileNamePrefix;
+ }
+
+ /**
+ * Set specifies the file name pattern <fileNamePrefix>_<fileIndex>.<fileExtension> when copy from non-file based store without partitionOptions. Type: string (or Expression with resultType string).
+ *
+ * @param fileNamePrefix the fileNamePrefix value to set
+ * @return the AvroWriteSettings object itself.
+ */
+ public AvroWriteSettings withFileNamePrefix(Object fileNamePrefix) {
+ this.fileNamePrefix = fileNamePrefix;
+ return this;
+ }
+
}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/CompressionReadSettings.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/CompressionReadSettings.java
index 0ccdda9e73593..f4f19174ce569 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/CompressionReadSettings.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/CompressionReadSettings.java
@@ -20,6 +20,8 @@
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "type", defaultImpl = CompressionReadSettings.class)
@JsonTypeName("CompressionReadSettings")
@JsonSubTypes({
+ @JsonSubTypes.Type(name = "TarGZipReadSettings", value = TarGZipReadSettings.class),
+ @JsonSubTypes.Type(name = "TarReadSettings", value = TarReadSettings.class),
@JsonSubTypes.Type(name = "ZipDeflateReadSettings", value = ZipDeflateReadSettings.class)
})
public class CompressionReadSettings {
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetCompression.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetCompression.java
index af32c35330c07..d51259d1d8ef4 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetCompression.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetCompression.java
@@ -20,6 +20,8 @@
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "type", defaultImpl = DatasetCompression.class)
@JsonTypeName("DatasetCompression")
@JsonSubTypes({
+ @JsonSubTypes.Type(name = "TarGZip", value = DatasetTarGZipCompression.class),
+ @JsonSubTypes.Type(name = "Tar", value = DatasetTarCompression.class),
@JsonSubTypes.Type(name = "ZipDeflate", value = DatasetZipDeflateCompression.class),
@JsonSubTypes.Type(name = "Deflate", value = DatasetDeflateCompression.class),
@JsonSubTypes.Type(name = "GZip", value = DatasetGZipCompression.class),
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetTarCompression.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetTarCompression.java
new file mode 100644
index 0000000000000..3b8499ad74340
--- /dev/null
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetTarCompression.java
@@ -0,0 +1,20 @@
+/**
+ * Copyright (c) Microsoft Corporation. All rights reserved.
+ * Licensed under the MIT License. See License.txt in the project root for
+ * license information.
+ *
+ * Code generated by Microsoft (R) AutoRest Code Generator.
+ */
+
+package com.microsoft.azure.management.datafactory.v2018_06_01;
+
+import com.fasterxml.jackson.annotation.JsonTypeInfo;
+import com.fasterxml.jackson.annotation.JsonTypeName;
+
+/**
+ * The Tar archive method used on a dataset.
+ */
+@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "type", defaultImpl = DatasetTarCompression.class)
+@JsonTypeName("Tar")
+public class DatasetTarCompression extends DatasetCompression {
+}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetTarGZipCompression.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetTarGZipCompression.java
new file mode 100644
index 0000000000000..b593bd54a84b0
--- /dev/null
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DatasetTarGZipCompression.java
@@ -0,0 +1,47 @@
+/**
+ * Copyright (c) Microsoft Corporation. All rights reserved.
+ * Licensed under the MIT License. See License.txt in the project root for
+ * license information.
+ *
+ * Code generated by Microsoft (R) AutoRest Code Generator.
+ */
+
+package com.microsoft.azure.management.datafactory.v2018_06_01;
+
+import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.annotation.JsonTypeInfo;
+import com.fasterxml.jackson.annotation.JsonTypeName;
+
+/**
+ * The TarGZip compression method used on a dataset.
+ */
+@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "type", defaultImpl = DatasetTarGZipCompression.class)
+@JsonTypeName("TarGZip")
+public class DatasetTarGZipCompression extends DatasetCompression {
+ /**
+ * The TarGZip compression level.
+ */
+ @JsonProperty(value = "level")
+ private Object level;
+
+ /**
+ * Get the TarGZip compression level.
+ *
+ * @return the level value
+ */
+ public Object level() {
+ return this.level;
+ }
+
+ /**
+ * Set the TarGZip compression level.
+ *
+ * @param level the level value to set
+ * @return the DatasetTarGZipCompression object itself.
+ */
+ public DatasetTarGZipCompression withLevel(Object level) {
+ this.level = level;
+ return this;
+ }
+
+}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DelimitedTextWriteSettings.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DelimitedTextWriteSettings.java
index b3053dda43828..1ab0f30b3c044 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DelimitedTextWriteSettings.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/DelimitedTextWriteSettings.java
@@ -32,6 +32,22 @@ public class DelimitedTextWriteSettings extends FormatWriteSettings {
@JsonProperty(value = "fileExtension", required = true)
private Object fileExtension;
+ /**
+ * Limit the written file's row count to be smaller than or equal to the
+ * specified count. Type: integer (or Expression with resultType integer).
+ */
+ @JsonProperty(value = "maxRowsPerFile")
+ private Object maxRowsPerFile;
+
+ /**
+ * Specifies the file name pattern
+ * <fileNamePrefix>_<fileIndex>.<fileExtension> when copy
+ * from non-file based store without partitionOptions. Type: string (or
+ * Expression with resultType string).
+ */
+ @JsonProperty(value = "fileNamePrefix")
+ private Object fileNamePrefix;
+
/**
* Get indicates whether string values should always be enclosed with quotes. Type: boolean (or Expression with resultType boolean).
*
@@ -72,4 +88,44 @@ public DelimitedTextWriteSettings withFileExtension(Object fileExtension) {
return this;
}
+ /**
+ * Get limit the written file's row count to be smaller than or equal to the specified count. Type: integer (or Expression with resultType integer).
+ *
+ * @return the maxRowsPerFile value
+ */
+ public Object maxRowsPerFile() {
+ return this.maxRowsPerFile;
+ }
+
+ /**
+ * Set limit the written file's row count to be smaller than or equal to the specified count. Type: integer (or Expression with resultType integer).
+ *
+ * @param maxRowsPerFile the maxRowsPerFile value to set
+ * @return the DelimitedTextWriteSettings object itself.
+ */
+ public DelimitedTextWriteSettings withMaxRowsPerFile(Object maxRowsPerFile) {
+ this.maxRowsPerFile = maxRowsPerFile;
+ return this;
+ }
+
+ /**
+ * Get specifies the file name pattern <fileNamePrefix>_<fileIndex>.<fileExtension> when copy from non-file based store without partitionOptions. Type: string (or Expression with resultType string).
+ *
+ * @return the fileNamePrefix value
+ */
+ public Object fileNamePrefix() {
+ return this.fileNamePrefix;
+ }
+
+ /**
+ * Set specifies the file name pattern <fileNamePrefix>_<fileIndex>.<fileExtension> when copy from non-file based store without partitionOptions. Type: string (or Expression with resultType string).
+ *
+ * @param fileNamePrefix the fileNamePrefix value to set
+ * @return the DelimitedTextWriteSettings object itself.
+ */
+ public DelimitedTextWriteSettings withFileNamePrefix(Object fileNamePrefix) {
+ this.fileNamePrefix = fileNamePrefix;
+ return this;
+ }
+
}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/FormatWriteSettings.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/FormatWriteSettings.java
index e02e451141739..b40ad1a076042 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/FormatWriteSettings.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/FormatWriteSettings.java
@@ -22,7 +22,9 @@
@JsonSubTypes({
@JsonSubTypes.Type(name = "JsonWriteSettings", value = JsonWriteSettings.class),
@JsonSubTypes.Type(name = "DelimitedTextWriteSettings", value = DelimitedTextWriteSettings.class),
- @JsonSubTypes.Type(name = "AvroWriteSettings", value = AvroWriteSettings.class)
+ @JsonSubTypes.Type(name = "OrcWriteSettings", value = OrcWriteSettings.class),
+ @JsonSubTypes.Type(name = "AvroWriteSettings", value = AvroWriteSettings.class),
+ @JsonSubTypes.Type(name = "ParquetWriteSettings", value = ParquetWriteSettings.class)
})
public class FormatWriteSettings {
/**
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/LogStorageSettings.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/LogStorageSettings.java
index 710cdce199e71..a9abe562e5a48 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/LogStorageSettings.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/LogStorageSettings.java
@@ -34,6 +34,20 @@ public class LogStorageSettings {
@JsonProperty(value = "path")
private Object path;
+ /**
+ * Gets or sets the log level, support: Info, Warning. Type: string (or
+ * Expression with resultType string).
+ */
+ @JsonProperty(value = "logLevel")
+ private Object logLevel;
+
+ /**
+ * Specifies whether to enable reliable logging. Type: boolean (or
+ * Expression with resultType boolean).
+ */
+ @JsonProperty(value = "enableReliableLogging")
+ private Object enableReliableLogging;
+
/**
* Get unmatched properties from the message are deserialized this collection.
*
@@ -94,4 +108,44 @@ public LogStorageSettings withPath(Object path) {
return this;
}
+ /**
+ * Get gets or sets the log level, support: Info, Warning. Type: string (or Expression with resultType string).
+ *
+ * @return the logLevel value
+ */
+ public Object logLevel() {
+ return this.logLevel;
+ }
+
+ /**
+ * Set gets or sets the log level, support: Info, Warning. Type: string (or Expression with resultType string).
+ *
+ * @param logLevel the logLevel value to set
+ * @return the LogStorageSettings object itself.
+ */
+ public LogStorageSettings withLogLevel(Object logLevel) {
+ this.logLevel = logLevel;
+ return this;
+ }
+
+ /**
+ * Get specifies whether to enable reliable logging. Type: boolean (or Expression with resultType boolean).
+ *
+ * @return the enableReliableLogging value
+ */
+ public Object enableReliableLogging() {
+ return this.enableReliableLogging;
+ }
+
+ /**
+ * Set specifies whether to enable reliable logging. Type: boolean (or Expression with resultType boolean).
+ *
+ * @param enableReliableLogging the enableReliableLogging value to set
+ * @return the LogStorageSettings object itself.
+ */
+ public LogStorageSettings withEnableReliableLogging(Object enableReliableLogging) {
+ this.enableReliableLogging = enableReliableLogging;
+ return this;
+ }
+
}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/OrcSink.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/OrcSink.java
index 32790cf107cb7..7a4ad1f6e8d4d 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/OrcSink.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/OrcSink.java
@@ -24,6 +24,12 @@ public class OrcSink extends CopySink {
@JsonProperty(value = "storeSettings")
private StoreWriteSettings storeSettings;
+ /**
+ * ORC format settings.
+ */
+ @JsonProperty(value = "formatSettings")
+ private OrcWriteSettings formatSettings;
+
/**
* Get oRC store settings.
*
@@ -44,4 +50,24 @@ public OrcSink withStoreSettings(StoreWriteSettings storeSettings) {
return this;
}
+ /**
+ * Get oRC format settings.
+ *
+ * @return the formatSettings value
+ */
+ public OrcWriteSettings formatSettings() {
+ return this.formatSettings;
+ }
+
+ /**
+ * Set oRC format settings.
+ *
+ * @param formatSettings the formatSettings value to set
+ * @return the OrcSink object itself.
+ */
+ public OrcSink withFormatSettings(OrcWriteSettings formatSettings) {
+ this.formatSettings = formatSettings;
+ return this;
+ }
+
}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/OrcWriteSettings.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/OrcWriteSettings.java
new file mode 100644
index 0000000000000..06e0f9fedb518
--- /dev/null
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/OrcWriteSettings.java
@@ -0,0 +1,77 @@
+/**
+ * Copyright (c) Microsoft Corporation. All rights reserved.
+ * Licensed under the MIT License. See License.txt in the project root for
+ * license information.
+ *
+ * Code generated by Microsoft (R) AutoRest Code Generator.
+ */
+
+package com.microsoft.azure.management.datafactory.v2018_06_01;
+
+import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.annotation.JsonTypeInfo;
+import com.fasterxml.jackson.annotation.JsonTypeName;
+
+/**
+ * Orc write settings.
+ */
+@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "type", defaultImpl = OrcWriteSettings.class)
+@JsonTypeName("OrcWriteSettings")
+public class OrcWriteSettings extends FormatWriteSettings {
+ /**
+ * Limit the written file's row count to be smaller than or equal to the
+ * specified count. Type: integer (or Expression with resultType integer).
+ */
+ @JsonProperty(value = "maxRowsPerFile")
+ private Object maxRowsPerFile;
+
+ /**
+ * Specifies the file name pattern
+ * <fileNamePrefix>_<fileIndex>.<fileExtension> when copy
+ * from non-file based store without partitionOptions. Type: string (or
+ * Expression with resultType string).
+ */
+ @JsonProperty(value = "fileNamePrefix")
+ private Object fileNamePrefix;
+
+ /**
+ * Get limit the written file's row count to be smaller than or equal to the specified count. Type: integer (or Expression with resultType integer).
+ *
+ * @return the maxRowsPerFile value
+ */
+ public Object maxRowsPerFile() {
+ return this.maxRowsPerFile;
+ }
+
+ /**
+ * Set limit the written file's row count to be smaller than or equal to the specified count. Type: integer (or Expression with resultType integer).
+ *
+ * @param maxRowsPerFile the maxRowsPerFile value to set
+ * @return the OrcWriteSettings object itself.
+ */
+ public OrcWriteSettings withMaxRowsPerFile(Object maxRowsPerFile) {
+ this.maxRowsPerFile = maxRowsPerFile;
+ return this;
+ }
+
+ /**
+ * Get specifies the file name pattern <fileNamePrefix>_<fileIndex>.<fileExtension> when copy from non-file based store without partitionOptions. Type: string (or Expression with resultType string).
+ *
+ * @return the fileNamePrefix value
+ */
+ public Object fileNamePrefix() {
+ return this.fileNamePrefix;
+ }
+
+ /**
+ * Set specifies the file name pattern <fileNamePrefix>_<fileIndex>.<fileExtension> when copy from non-file based store without partitionOptions. Type: string (or Expression with resultType string).
+ *
+ * @param fileNamePrefix the fileNamePrefix value to set
+ * @return the OrcWriteSettings object itself.
+ */
+ public OrcWriteSettings withFileNamePrefix(Object fileNamePrefix) {
+ this.fileNamePrefix = fileNamePrefix;
+ return this;
+ }
+
+}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/ParquetSink.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/ParquetSink.java
index 518020b0239b6..fd25f074434ad 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/ParquetSink.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/ParquetSink.java
@@ -24,6 +24,12 @@ public class ParquetSink extends CopySink {
@JsonProperty(value = "storeSettings")
private StoreWriteSettings storeSettings;
+ /**
+ * Parquet format settings.
+ */
+ @JsonProperty(value = "formatSettings")
+ private ParquetWriteSettings formatSettings;
+
/**
* Get parquet store settings.
*
@@ -44,4 +50,24 @@ public ParquetSink withStoreSettings(StoreWriteSettings storeSettings) {
return this;
}
+ /**
+ * Get parquet format settings.
+ *
+ * @return the formatSettings value
+ */
+ public ParquetWriteSettings formatSettings() {
+ return this.formatSettings;
+ }
+
+ /**
+ * Set parquet format settings.
+ *
+ * @param formatSettings the formatSettings value to set
+ * @return the ParquetSink object itself.
+ */
+ public ParquetSink withFormatSettings(ParquetWriteSettings formatSettings) {
+ this.formatSettings = formatSettings;
+ return this;
+ }
+
}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/ParquetWriteSettings.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/ParquetWriteSettings.java
new file mode 100644
index 0000000000000..969d23fa97206
--- /dev/null
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/ParquetWriteSettings.java
@@ -0,0 +1,77 @@
+/**
+ * Copyright (c) Microsoft Corporation. All rights reserved.
+ * Licensed under the MIT License. See License.txt in the project root for
+ * license information.
+ *
+ * Code generated by Microsoft (R) AutoRest Code Generator.
+ */
+
+package com.microsoft.azure.management.datafactory.v2018_06_01;
+
+import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.annotation.JsonTypeInfo;
+import com.fasterxml.jackson.annotation.JsonTypeName;
+
+/**
+ * Parquet write settings.
+ */
+@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "type", defaultImpl = ParquetWriteSettings.class)
+@JsonTypeName("ParquetWriteSettings")
+public class ParquetWriteSettings extends FormatWriteSettings {
+ /**
+ * Limit the written file's row count to be smaller than or equal to the
+ * specified count. Type: integer (or Expression with resultType integer).
+ */
+ @JsonProperty(value = "maxRowsPerFile")
+ private Object maxRowsPerFile;
+
+ /**
+ * Specifies the file name pattern
+ * <fileNamePrefix>_<fileIndex>.<fileExtension> when copy
+ * from non-file based store without partitionOptions. Type: string (or
+ * Expression with resultType string).
+ */
+ @JsonProperty(value = "fileNamePrefix")
+ private Object fileNamePrefix;
+
+ /**
+ * Get limit the written file's row count to be smaller than or equal to the specified count. Type: integer (or Expression with resultType integer).
+ *
+ * @return the maxRowsPerFile value
+ */
+ public Object maxRowsPerFile() {
+ return this.maxRowsPerFile;
+ }
+
+ /**
+ * Set limit the written file's row count to be smaller than or equal to the specified count. Type: integer (or Expression with resultType integer).
+ *
+ * @param maxRowsPerFile the maxRowsPerFile value to set
+ * @return the ParquetWriteSettings object itself.
+ */
+ public ParquetWriteSettings withMaxRowsPerFile(Object maxRowsPerFile) {
+ this.maxRowsPerFile = maxRowsPerFile;
+ return this;
+ }
+
+ /**
+ * Get specifies the file name pattern <fileNamePrefix>_<fileIndex>.<fileExtension> when copy from non-file based store without partitionOptions. Type: string (or Expression with resultType string).
+ *
+ * @return the fileNamePrefix value
+ */
+ public Object fileNamePrefix() {
+ return this.fileNamePrefix;
+ }
+
+ /**
+ * Set specifies the file name pattern <fileNamePrefix>_<fileIndex>.<fileExtension> when copy from non-file based store without partitionOptions. Type: string (or Expression with resultType string).
+ *
+ * @param fileNamePrefix the fileNamePrefix value to set
+ * @return the ParquetWriteSettings object itself.
+ */
+ public ParquetWriteSettings withFileNamePrefix(Object fileNamePrefix) {
+ this.fileNamePrefix = fileNamePrefix;
+ return this;
+ }
+
+}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/TarGZipReadSettings.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/TarGZipReadSettings.java
new file mode 100644
index 0000000000000..bcbfeaff2d4f5
--- /dev/null
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/TarGZipReadSettings.java
@@ -0,0 +1,48 @@
+/**
+ * Copyright (c) Microsoft Corporation. All rights reserved.
+ * Licensed under the MIT License. See License.txt in the project root for
+ * license information.
+ *
+ * Code generated by Microsoft (R) AutoRest Code Generator.
+ */
+
+package com.microsoft.azure.management.datafactory.v2018_06_01;
+
+import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.annotation.JsonTypeInfo;
+import com.fasterxml.jackson.annotation.JsonTypeName;
+
+/**
+ * The TarGZip compression read settings.
+ */
+@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "type", defaultImpl = TarGZipReadSettings.class)
+@JsonTypeName("TarGZipReadSettings")
+public class TarGZipReadSettings extends CompressionReadSettings {
+ /**
+ * Preserve the compression file name as folder path. Type: boolean (or
+ * Expression with resultType boolean).
+ */
+ @JsonProperty(value = "preserveCompressionFileNameAsFolder")
+ private Object preserveCompressionFileNameAsFolder;
+
+ /**
+ * Get preserve the compression file name as folder path. Type: boolean (or Expression with resultType boolean).
+ *
+ * @return the preserveCompressionFileNameAsFolder value
+ */
+ public Object preserveCompressionFileNameAsFolder() {
+ return this.preserveCompressionFileNameAsFolder;
+ }
+
+ /**
+ * Set preserve the compression file name as folder path. Type: boolean (or Expression with resultType boolean).
+ *
+ * @param preserveCompressionFileNameAsFolder the preserveCompressionFileNameAsFolder value to set
+ * @return the TarGZipReadSettings object itself.
+ */
+ public TarGZipReadSettings withPreserveCompressionFileNameAsFolder(Object preserveCompressionFileNameAsFolder) {
+ this.preserveCompressionFileNameAsFolder = preserveCompressionFileNameAsFolder;
+ return this;
+ }
+
+}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/TarReadSettings.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/TarReadSettings.java
new file mode 100644
index 0000000000000..f6ac2fa41626f
--- /dev/null
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/TarReadSettings.java
@@ -0,0 +1,48 @@
+/**
+ * Copyright (c) Microsoft Corporation. All rights reserved.
+ * Licensed under the MIT License. See License.txt in the project root for
+ * license information.
+ *
+ * Code generated by Microsoft (R) AutoRest Code Generator.
+ */
+
+package com.microsoft.azure.management.datafactory.v2018_06_01;
+
+import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.annotation.JsonTypeInfo;
+import com.fasterxml.jackson.annotation.JsonTypeName;
+
+/**
+ * The Tar compression read settings.
+ */
+@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "type", defaultImpl = TarReadSettings.class)
+@JsonTypeName("TarReadSettings")
+public class TarReadSettings extends CompressionReadSettings {
+ /**
+ * Preserve the compression file name as folder path. Type: boolean (or
+ * Expression with resultType boolean).
+ */
+ @JsonProperty(value = "preserveCompressionFileNameAsFolder")
+ private Object preserveCompressionFileNameAsFolder;
+
+ /**
+ * Get preserve the compression file name as folder path. Type: boolean (or Expression with resultType boolean).
+ *
+ * @return the preserveCompressionFileNameAsFolder value
+ */
+ public Object preserveCompressionFileNameAsFolder() {
+ return this.preserveCompressionFileNameAsFolder;
+ }
+
+ /**
+ * Set preserve the compression file name as folder path. Type: boolean (or Expression with resultType boolean).
+ *
+ * @param preserveCompressionFileNameAsFolder the preserveCompressionFileNameAsFolder value to set
+ * @return the TarReadSettings object itself.
+ */
+ public TarReadSettings withPreserveCompressionFileNameAsFolder(Object preserveCompressionFileNameAsFolder) {
+ this.preserveCompressionFileNameAsFolder = preserveCompressionFileNameAsFolder;
+ return this;
+ }
+
+}
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/DataFlowInner.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/DataFlowInner.java
index ae6b5b3cdcbdd..640ce52d1e970 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/DataFlowInner.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/DataFlowInner.java
@@ -14,7 +14,6 @@
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonSubTypes;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MappingDataFlow;
/**
* Azure Data Factory nested object which contains a flow with data movements
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/DatasetInner.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/DatasetInner.java
index 36a1d9211b326..e6a553623dcae 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/DatasetInner.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/DatasetInner.java
@@ -9,67 +9,7 @@
package com.microsoft.azure.management.datafactory.v2018_06_01.implementation;
import java.util.Map;
-
-import com.microsoft.azure.management.datafactory.v2018_06_01.AmazonMWSObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AmazonRedshiftTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AmazonS3Dataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AvroDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureBlobDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureBlobFSDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureDataExplorerTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureDataLakeStoreDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureMariaDBTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureMySqlTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzurePostgreSqlTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureSearchIndexDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureSqlDWTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureSqlMITableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureSqlTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.BinaryDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CassandraTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CommonDataServiceForAppsEntityDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ConcurObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CosmosDbMongoDbApiCollectionDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CosmosDbSqlApiCollectionDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CouchbaseTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CustomDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.Db2TableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DelimitedTextDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DocumentDbCollectionDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DrillTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DynamicsAXResourceDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DynamicsCrmEntityDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DynamicsEntityDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.EloquaObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ExcelDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.FileShareDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.GoogleAdWordsObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.GoogleBigQueryObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.GreenplumTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HBaseObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HiveObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HttpDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HubspotObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ImpalaObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.InformixTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.JiraObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.JsonDataset;
import com.microsoft.azure.management.datafactory.v2018_06_01.LinkedServiceReference;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MagentoObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MariaDBTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MarketoObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MicrosoftAccessTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MongoDbCollectionDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MongoDbV2CollectionDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MySqlTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.NetezzaTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ODataResourceDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.OdbcTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.Office365Dataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.OracleServiceCloudObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.OracleTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.OrcDataset;
import com.microsoft.azure.management.datafactory.v2018_06_01.ParameterSpecification;
import java.util.List;
import com.microsoft.azure.management.datafactory.v2018_06_01.DatasetFolder;
@@ -77,38 +17,6 @@
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonSubTypes;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ParquetDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.PaypalObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.PhoenixObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.PostgreSqlTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.PrestoObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.QuickBooksObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.RelationalTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ResponsysObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.RestResourceDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SalesforceMarketingCloudObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SalesforceObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SalesforceServiceCloudObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapBwCubeDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapCloudForCustomerResourceDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapEccResourceDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapHanaTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapOpenHubTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapTableResourceDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ServiceNowObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SharePointOnlineListResourceDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ShopifyObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SnowflakeDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SparkObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SqlServerTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SquareObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SybaseTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.TeradataTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.VerticaTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.WebTableDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.XeroObjectDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.XmlDataset;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ZohoObjectDataset;
/**
* The Azure Data Factory nested object which identifies data within different
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/IntegrationRuntimeInner.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/IntegrationRuntimeInner.java
index 714c12e9db2ec..58b27acef3ca8 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/IntegrationRuntimeInner.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/IntegrationRuntimeInner.java
@@ -13,8 +13,6 @@
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonSubTypes;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ManagedIntegrationRuntime;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SelfHostedIntegrationRuntime;
/**
* Azure Data Factory nested object which serves as a compute resource for
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/LinkedServiceInner.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/LinkedServiceInner.java
index 17b7121541662..a11d27d96022e 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/LinkedServiceInner.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/LinkedServiceInner.java
@@ -9,110 +9,13 @@
package com.microsoft.azure.management.datafactory.v2018_06_01.implementation;
import java.util.Map;
-
-import com.microsoft.azure.management.datafactory.v2018_06_01.AmazonMWSLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AmazonRedshiftLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AmazonS3LinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureBatchLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureBlobFSLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureBlobStorageLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureDataExplorerLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureDataLakeAnalyticsLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureDataLakeStoreLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureDatabricksLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureFileStorageLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureFunctionLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureKeyVaultLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureMLLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureMLServiceLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureMariaDBLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureMySqlLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzurePostgreSqlLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureSearchLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureSqlDWLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureSqlDatabaseLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureSqlMILinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureStorageLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.AzureTableStorageLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CassandraLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CommonDataServiceForAppsLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ConcurLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CosmosDbLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CosmosDbMongoDbApiLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CouchbaseLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.CustomDataSourceLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.Db2LinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DrillLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DynamicsAXLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DynamicsCrmLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.DynamicsLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.EloquaLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.FileServerLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.FtpServerLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.GoogleAdWordsLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.GoogleBigQueryLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.GoogleCloudStorageLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.GreenplumLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HBaseLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HDInsightLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HDInsightOnDemandLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HdfsLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HiveLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HttpLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.HubspotLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ImpalaLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.InformixLinkedService;
import com.microsoft.azure.management.datafactory.v2018_06_01.IntegrationRuntimeReference;
-import com.microsoft.azure.management.datafactory.v2018_06_01.JiraLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MagentoLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MariaDBLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MarketoLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MicrosoftAccessLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MongoDbLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MongoDbV2LinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MySqlLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.NetezzaLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ODataLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.OdbcLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.Office365LinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.OracleLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.OracleServiceCloudLinkedService;
import com.microsoft.azure.management.datafactory.v2018_06_01.ParameterSpecification;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonSubTypes;
-import com.microsoft.azure.management.datafactory.v2018_06_01.PaypalLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.PhoenixLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.PostgreSqlLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.PrestoLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.QuickBooksLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ResponsysLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.RestServiceLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SalesforceLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SalesforceMarketingCloudLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SalesforceServiceCloudLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapBWLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapCloudForCustomerLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapEccLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapHanaLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapOpenHubLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SapTableLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ServiceNowLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SftpServerLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SharePointOnlineListLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ShopifyLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SnowflakeLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SparkLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SqlServerLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SquareLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.SybaseLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.TeradataLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.VerticaLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.WebLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.XeroLinkedService;
-import com.microsoft.azure.management.datafactory.v2018_06_01.ZohoLinkedService;
/**
* The Azure Data Factory nested object which contains the information and
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/TriggerInner.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/TriggerInner.java
index 275a137e2dab6..d6a5e12c92a21 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/TriggerInner.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/implementation/TriggerInner.java
@@ -9,17 +9,12 @@
package com.microsoft.azure.management.datafactory.v2018_06_01.implementation;
import java.util.Map;
-
-import com.microsoft.azure.management.datafactory.v2018_06_01.ChainingTrigger;
-import com.microsoft.azure.management.datafactory.v2018_06_01.MultiplePipelineTrigger;
-import com.microsoft.azure.management.datafactory.v2018_06_01.RerunTumblingWindowTrigger;
import com.microsoft.azure.management.datafactory.v2018_06_01.TriggerRuntimeState;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonSubTypes;
-import com.microsoft.azure.management.datafactory.v2018_06_01.TumblingWindowTrigger;
/**
* Azure data factory nested object which contains information about creating
diff --git a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/RestSink.java b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/RestSink.java
index b554b939e6be3..6bd1c1ada12c1 100644
--- a/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/RestSink.java
+++ b/sdk/datafactory/mgmt-v2018_06_01/src/main/java/com/microsoft/azure/management/datafactory/v2018_06_01/RestSink.java
@@ -48,20 +48,12 @@ public class RestSink extends CopySink {
private Object requestInterval;
/**
* Compression Type to Send data in compressed format with Optimal
* Compression Level, Default is None. And The Only Supported option is
* Gzip.
*/
- @JsonProperty(value = "compressionType")
- private Object compressionType;
-
- /**
- * Wraps Request Array Json into an Object before calling the rest endpoint
- * , Default is false. ex: if true request content sample format is {
- * rows:[]} else the format is [].
- */
- @JsonProperty(value = "wrapRequestJsonInAnObject")
- private Object wrapRequestJsonInAnObject;
+ @JsonProperty(value = "httpCompressionType")
+ private Object httpCompressionType;
/**
* Get the HTTP method used to call the RESTful API. The default is POST. Type: string (or Expression with resultType string).
@@ -144,42 +136,22 @@ public RestSink withRequestInterval(Object requestInterval) {
}
/**
- * Get compression Type to Send data in compressed format with Optimal Compression Level, Default is None. And The Only Supported option is Gzip.
- *
- * @return the compressionType value
- */
- public Object compressionType() {
- return this.compressionType;
- }
-
- /**
- * Set compression Type to Send data in compressed format with Optimal Compression Level, Default is None. And The Only Supported option is Gzip.
- *
- * @param compressionType the compressionType value to set
- * @return the RestSink object itself.
- */
- public RestSink withCompressionType(Object compressionType) {
- this.compressionType = compressionType;
- return this;
- }
-
- /**
- * Get wraps Request Array Json into an Object before calling the rest endpoint , Default is false. ex: if true request content sample format is { rows:[]} else the format is [].
+ * Get http Compression Type to Send data in compressed format with Optimal Compression Level, Default is None. And The Only Supported option is Gzip.
*
- * @return the wrapRequestJsonInAnObject value
+ * @return the httpCompressionType value
*/
- public Object wrapRequestJsonInAnObject() {
- return this.wrapRequestJsonInAnObject;
+ public Object httpCompressionType() {
+ return this.httpCompressionType;
}
/**
- * Set wraps Request Array Json into an Object before calling the rest endpoint , Default is false. ex: if true request content sample format is { rows:[]} else the format is [].
+ * Set http Compression Type to Send data in compressed format with Optimal Compression Level, Default is None. And The Only Supported option is Gzip.
*
- * @param wrapRequestJsonInAnObject the wrapRequestJsonInAnObject value to set
+ * @param httpCompressionType the httpCompressionType value to set
* @return the RestSink object itself.
*/
- public RestSink withWrapRequestJsonInAnObject(Object wrapRequestJsonInAnObject) {
- this.wrapRequestJsonInAnObject = wrapRequestJsonInAnObject;
+ public RestSink withHttpCompressionType(Object httpCompressionType) {
+ this.httpCompressionType = httpCompressionType;
return this;
}
@@ -48,20 +48,12 @@ public class RestSink extends CopySink {
private Object requestInterval;
/**
- * Compression Type to Send data in compressed format with Optimal
+ * Http Compression Type to Send data in compressed format with Optimal
* Compression Level, Default is None. And The Only Supported option is
* Gzip.